==> tardy_1.11.orig.tar.gz: tardy-1.11/test/00/t0012a.sh <==
#!/bin/sh
#
#	tardy - a tar post-processor
#	Copyright (C) 1998, 1999 Peter Miller;
#	All rights reserved.
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
#
# MANIFEST: Test the cpio output functionality
#

umask 022

USER=${USER:-${LOGNAME:-`whoami`}}

work=/tmp/$$
PAGER=cat
export PAGER

here=`pwd`
if test $? -ne 0 ; then exit 1; fi

if test "$1" != "" ; then bin="$here/$1/bin"; else bin="$here/bin"; fi

pass()
{
	set +x
	echo PASSED 1>&2
	cd $here
	find $work -type d -user $USER -exec chmod u+w {} \;
	rm -rf $work
	exit 0
}
fail()
{
	set +x
	echo 'FAILED test of the cpio output functionality' 1>&2
	cd $here
	find $work -type d -user $USER -exec chmod u+w {} \;
	rm -rf $work
	exit 1
}
no_result()
{
	set +x
	echo 'NO RESULT for test of the cpio output functionality' 1>&2
	cd $here
	find $work -type d -user $USER -exec chmod u+w {} \;
	rm -rf $work
	exit 2
}
trap \"no_result\" 1 2 3 15

mkdir $work
if test $? -ne 0 ; then no_result; fi
cd $work
if test $? -ne 0 ; then no_result; fi

#
# build a directory tree
#
mkdir a b
if test $? -ne 0 ; then no_result; fi
echo cc > a/cc
if test $? -ne 0 ; then no_result; fi
echo ddd > a/ddd
if test $? -ne 0 ; then no_result; fi
echo eeee > b/eeee
if test $? -ne 0 ; then no_result; fi
echo fffff > b/fffff
if test $? -ne 0 ; then no_result; fi

#
# make sure cpio is out there
#
find a b -print > x
if test $? -ne 0 ; then no_result; fi
cpio -o < x > x.cpio 2> LOG
if test $? -ne 0 ; then cat LOG; no_result; fi

#
# test the cpio output functionality
#
tar -cf x.tar a b
if test $? -ne 0 ; then no_result; fi
$bin/tardy -now -output-format=newascii x.tar x.cpio2
if test $? -ne 0 ; then fail; fi

#
# make sure cpio accepts it
#	(How portable is this?  How many cpios accept all the formats?)
#
cpio -i -t < x.cpio2 > x.list1
if test $? -ne 0 ; then fail; fi

#
# make sure it looks right
#
sort x.list1 > x.list2
if test $? -ne 0 ; then no_result; fi
cat > ok << 'fubar'
a
a/cc
a/ddd
b
b/eeee
b/fffff
fubar
if test $? -ne 0 ; then no_result; fi
diff ok x.list2
if test $? -ne 0 ; then fail; fi

#
# Only definite negatives are possible.
# The functionality exercised by this test appears to work,
# no other guarantees are made.
#
pass

==> tardy_1.12.orig.tar.gz: tardy-1.12/test/00/t0012a.sh <==
#!/bin/sh
#
#	tardy - a tar post-processor
#	Copyright (C) 1998, 1999, 2004 Peter Miller;
#	All rights reserved.
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
#
# MANIFEST: Test the cpio output functionality
#

umask 022

USER=${USER:-${LOGNAME:-`whoami`}}

work=/tmp/$$
PAGER=cat
export PAGER

here=`pwd`
if test $? -ne 0 ; then exit 1; fi

if test "$1" != "" ; then bin="$here/$1/bin"; else bin="$here/bin"; fi

pass()
{
	set +x
	echo PASSED 1>&2
	cd $here
	find $work -type d -user $USER -exec chmod u+w {} \;
	rm -rf $work
	exit 0
}
fail()
{
	set +x
	echo 'FAILED test of the cpio output functionality' 1>&2
	cd $here
	find $work -type d -user $USER -exec chmod u+w {} \;
	rm -rf $work
	exit 1
}
no_result()
{
	set +x
	echo 'NO RESULT for test of the cpio output functionality' 1>&2
	cd $here
	find $work -type d -user $USER -exec chmod u+w {} \;
	rm -rf $work
	exit 2
}
trap \"no_result\" 1 2 3 15

mkdir $work
if test $? -ne 0 ; then no_result; fi
cd $work
if test $? -ne 0 ; then no_result; fi

#
# build a directory tree
#
mkdir a b
if test $? -ne 0 ; then no_result; fi
echo cc > a/cc
if test $? -ne 0 ; then no_result; fi
echo ddd > a/ddd
if test $? -ne 0 ; then no_result; fi
echo eeee > b/eeee
if test $? -ne 0 ; then no_result; fi
echo fffff > b/fffff
if test $? -ne 0 ; then no_result; fi

#
# make sure cpio is out there
#
find a b -print > x
if test $? -ne 0 ; then no_result; fi
cpio -o < x > x.cpio 2> LOG
if test $? -ne 0 ; then cat LOG; no_result; fi

#
# test the cpio output functionality
#
tar -cf x.tar a b
if test $? -ne 0 ; then no_result; fi
$bin/tardy -now -output-format=newascii x.tar x.cpio2
if test $? -ne 0 ; then fail; fi

#
# make sure cpio accepts it
#	(How portable is this?  How many cpios accept all the formats?)
#
cpio -i -t < x.cpio2 > x.list1 2> LOG
if test $? -ne 0 ; then cat LOG; fail; fi

#
# make sure it looks right
#
sort x.list1 > x.list2
if test $? -ne 0 ; then no_result; fi
cat > ok << 'fubar'
a
a/cc
a/ddd
b
b/eeee
b/fffff
fubar
if test $? -ne 0 ; then no_result; fi
diff ok x.list2
if test $? -ne 0 ; then fail; fi

#
# Only definite negatives are possible.
# The functionality exercised by this test appears to work,
# no other guarantees are made.
#
pass
